@@ -73,6 +73,16 @@ class WebServiceClient(object):
         self._do_get_request(path, query)
 
     def edit(self, path, obj_id, obj_dict):
+        if obj_id is None:
+            self._edit(path, obj_dict)
+        else:
+            self._edit_with_id(path, obj_id, obj_dict)
+
+    def _edit(self, path, obj_dict):
+        query = u'act=edit'
+        self._do_post_request(path, query, obj_dict)
+
+    def _edit_with_id(self, path, obj_id, obj_dict):
         query = u'act=edit&id=%s' % quote_plus(unicode(obj_id))
         self._do_post_request(path, query, obj_dict)
 
@@ -92,8 +102,10 @@ class WebServiceClient(object):
         query = u'act=search&search=%s' % quote_plus(search_pattern.encode('utf8'))
         return self._do_list_or_search_request(path, query)
 
-    def view(self, path, obj_id):
-        query = u'act=view&id=%s' % quote_plus(unicode(obj_id))
+    def view(self, path, obj_id=None):
+        query = u'act=view'
+        if obj_id is not None:
+            query += "&id=%s" % quote_plus(unicode(obj_id))
         response_content = self._do_get_request(path, query)
         obj_dict = json.loads(response_content)
         return obj_dict
